@@ -1,7 +1,5 @@
 /* This is a generated file, edit the .stub.php file instead.
- * Stub hash: 50b960193f55c7b09316355a0c0ae1d572ca9694 */
-
-
+ * Stub hash: 65be08c1bdace83ad1fa1175fc824262e07eac2a */
 
 static void register_zend_constants_symbols(int module_number)
 {
@@ -16,9 +14,16 @@ static void register_zend_constants_symbols(int module_number)
 	REGISTER_LONG_CONSTANT("E_USER_ERROR", E_USER_ERROR, CONST_PERSISTENT);
 	REGISTER_LONG_CONSTANT("E_USER_WARNING", E_USER_WARNING, CONST_PERSISTENT);
 	REGISTER_LONG_CONSTANT("E_USER_NOTICE", E_USER_NOTICE, CONST_PERSISTENT);
-	REGISTER_LONG_CONSTANT("E_STRICT", E_STRICT, CONST_PERSISTENT);
+	REGISTER_LONG_CONSTANT("E_STRICT", E_STRICT, CONST_PERSISTENT | CONST_DEPRECATED);
 	REGISTER_LONG_CONSTANT("E_RECOVERABLE_ERROR", E_RECOVERABLE_ERROR, CONST_PERSISTENT);
 	REGISTER_LONG_CONSTANT("E_DEPRECATED", E_DEPRECATED, CONST_PERSISTENT);
 	REGISTER_LONG_CONSTANT("E_USER_DEPRECATED", E_USER_DEPRECATED, CONST_PERSISTENT);
 	REGISTER_LONG_CONSTANT("E_ALL", E_ALL, CONST_PERSISTENT);
+	REGISTER_LONG_CONSTANT("DEBUG_BACKTRACE_PROVIDE_OBJECT", DEBUG_BACKTRACE_PROVIDE_OBJECT, CONST_PERSISTENT);
+	REGISTER_LONG_CONSTANT("DEBUG_BACKTRACE_IGNORE_ARGS", DEBUG_BACKTRACE_IGNORE_ARGS, CONST_PERSISTENT);
+	REGISTER_BOOL_CONSTANT("ZEND_THREAD_SAFE", ZTS_V, CONST_PERSISTENT);
+	REGISTER_BOOL_CONSTANT("ZEND_DEBUG_BUILD", ZEND_DEBUG, CONST_PERSISTENT);
+	REGISTER_BOOL_CONSTANT("TRUE", true, CONST_PERSISTENT);
+	REGISTER_BOOL_CONSTANT("FALSE", false, CONST_PERSISTENT);
+	REGISTER_NULL_CONSTANT("NULL", CONST_PERSISTENT);
 }
